@@ -11,10 +11,6 @@
 #include "kfind_p.h"
 #include "kreplacedialog.h"
 
-#if KTEXTWIDGETS_BUILD_DEPRECATED_SINCE(5, 70)
-#include <QRegExp>
-#endif
-
 #include <QDialogButtonBox>
 #include <QLabel>
 #include <QPushButton>
@@ -111,9 +107,9 @@ public:
     KReplaceNextDialog *nextDialog();
     void doReplace();
 
-    void _k_slotSkip();
-    void _k_slotReplace();
-    void _k_slotReplaceAll();
+    void slotSkip();
+    void slotReplace();
+    void slotReplaceAll();
 
     QString m_replacement;
     int m_replacements = 0;
@@ -157,10 +153,18 @@ KReplaceNextDialog *KReplacePrivate::nextDialog()
 
     if (!dialog) {
         auto *nextDialog = new KReplaceNextDialog(q->parentWidget());
-        q->connect(nextDialog->replaceAllButton(), SIGNAL(clicked()), q, SLOT(_k_slotReplaceAll()));
-        q->connect(nextDialog->skipButton(), SIGNAL(clicked()), q, SLOT(_k_slotSkip()));
-        q->connect(nextDialog->replaceButton(), SIGNAL(clicked()), q, SLOT(_k_slotReplace()));
-        q->connect(nextDialog, SIGNAL(finished(int)), q, SLOT(_k_slotDialogClosed()));
+        q->connect(nextDialog->replaceAllButton(), &QPushButton::clicked, q, [this]() {
+            slotReplaceAll();
+        });
+        q->connect(nextDialog->skipButton(), &QPushButton::clicked, q, [this]() {
+            slotSkip();
+        });
+        q->connect(nextDialog->replaceButton(), &QPushButton::clicked, q, [this]() {
+            slotReplace();
+        });
+        q->connect(nextDialog, &QDialog::finished, q, [this]() {
+            slotDialogClosed();
+        });
         dialog = nextDialog;
     }
     return static_cast<KReplaceNextDialog *>(dialog);
@@ -177,29 +181,6 @@ void KReplace::displayFinalDialog() const
     }
 }
 
-#if KTEXTWIDGETS_BUILD_DEPRECATED_SINCE(5, 70)
-static int replaceHelper(QString &text, const QString &replacement, int index, long options, int length, const QRegExp *regExp)
-{
-    QString rep(replacement);
-    if (options & KReplaceDialog::BackReference) {
-        // Backreferences: replace \0 with the right portion of 'text'
-        rep.replace(QLatin1String("\\0"), text.mid(index, length));
-
-        // Other backrefs
-        if (regExp) {
-            const QStringList caps = regExp->capturedTexts();
-            for (int i = 0; i < caps.count(); ++i) {
-                rep.replace(QLatin1String("\\") + QString::number(i), caps.at(i));
-            }
-        }
-    }
-
-    // Then replace rep into the text
-    text.replace(index, length, rep);
-    return rep.length();
-}
-#endif
-
 static int replaceHelper(QString &text, const QString &replacement, int index, long options, const QRegularExpressionMatch *match, int length)
 {
     QString rep(replacement);
@@ -260,9 +241,6 @@ KFind::Result KReplace::replace()
 
                     // Tell the world about the match we found, in case someone wants to
                     // highlight it.
-#if KTEXTWIDGETS_BUILD_DEPRECATED_SINCE(5, 81)
-                    Q_EMIT highlight(d->text, d->index, d->matchedLength);
-#endif
                     Q_EMIT textFound(d->text, d->index, d->matchedLength);
 
                     d->lastResult = Match;
@@ -304,25 +282,7 @@ int KReplace::replace(QString &text, const QString &pattern, const QString &repl
     return index;
 }
 
-#if KTEXTWIDGETS_BUILD_DEPRECATED_SINCE(5, 70)
-int KReplace::replace(QString &text, const QRegExp &pattern, const QString &replacement, int index, long options, int *replacedLength)
-{
-    int matchedLength;
-
-    index = KFind::find(text, pattern, index, options, &matchedLength);
-    if (index != -1) {
-        *replacedLength = replaceHelper(text, replacement, index, options, matchedLength, &pattern);
-        if (options & KFind::FindBackwards) {
-            index--;
-        } else {
-            index += *replacedLength;
-        }
-    }
-    return index;
-}
-#endif
-
-void KReplacePrivate::_k_slotReplaceAll()
+void KReplacePrivate::slotReplaceAll()
 {
     Q_Q(KReplace);
 
@@ -332,7 +292,7 @@ void KReplacePrivate::_k_slotReplaceAll()
     Q_EMIT q->findNext();
 }
 
-void KReplacePrivate::_k_slotSkip()
+void KReplacePrivate::slotSkip()
 {
     Q_Q(KReplace);
 
@@ -349,7 +309,7 @@ void KReplacePrivate::_k_slotSkip()
     }
 }
 
-void KReplacePrivate::_k_slotReplace()
+void KReplacePrivate::slotReplace()
 {
     Q_Q(KReplace);
 
@@ -371,7 +331,8 @@ void KReplacePrivate::doReplace()
 
     // Tell the world about the replacement we made, in case someone wants to
     // highlight it.
-    Q_EMIT q->replace(text, index, replacedLength, matchedLength);
+    Q_EMIT q->textReplaced(text, index, replacedLength, matchedLength);
+
 #ifdef DEBUG_REPLACE
     // qDebug() << "after replace() signal: d->index=" << d->index << " replacedLength=" << replacedLength;
 #endif
@@ -387,7 +348,7 @@ void KReplacePrivate::doReplace()
         }
     }
 #ifdef DEBUG_REPLACE
-    // qDebug() << "after adjustement: d->index=" << d->index;
+    // qDebug() << "after adjustment: d->index=" << d->index;
 #endif
 }
 
@@ -431,12 +392,12 @@ bool KReplace::shouldRestart(bool forceAsking, bool showNumMatches) const
     message +=
         (d->options & KFind::FindBackwards) ? i18n("Do you want to restart search from the end?") : i18n("Do you want to restart search at the beginning?");
 
-    int ret = KMessageBox::questionYesNo(parentWidget(),
-                                         message,
-                                         QString(),
-                                         KGuiItem(i18nc("@action:button Restart find & replace", "Restart")),
-                                         KGuiItem(i18nc("@action:button Stop find & replace", "Stop")));
-    return (ret == KMessageBox::Yes);
+    int ret = KMessageBox::questionTwoActions(parentWidget(),
+                                              message,
+                                              QString(),
+                                              KGuiItem(i18nc("@action:button Restart find & replace", "Restart")),
+                                              KGuiItem(i18nc("@action:button Stop find & replace", "Stop")));
+    return (ret == KMessageBox::PrimaryAction);
 }
 
 void KReplace::closeReplaceNextDialog()
