@@ -6,13 +6,17 @@
 
 #include "kpluralhandlingspinbox.h"
 
-class Q_DECL_HIDDEN KPluralHandlingSpinBox::KPluralHandlingSpinBoxPrivate
+#if KTEXTWIDGETS_BUILD_DEPRECATED_SINCE(6, 6)
+
+class KPluralHandlingSpinBoxPrivate
 {
 public:
-    KPluralHandlingSpinBoxPrivate(QSpinBox *q)
-        : q(q)
+    KPluralHandlingSpinBoxPrivate(QSpinBox *qq)
+        : q(qq)
     {
-        connect(q, SIGNAL(valueChanged(int)), q, SLOT(updateSuffix(int)));
+        QObject::connect(q, qOverload<int>(&QSpinBox::valueChanged), q, [this](int value) {
+            updateSuffix(value);
+        });
     }
 
     void updateSuffix(int value)
@@ -27,17 +31,13 @@ public:
     KLocalizedString pluralSuffix;
 };
 
-
 KPluralHandlingSpinBox::KPluralHandlingSpinBox(QWidget *parent)
-    : QSpinBox(parent),
-      d(new KPluralHandlingSpinBoxPrivate(this))
+    : QSpinBox(parent)
+    , d(new KPluralHandlingSpinBoxPrivate(this))
 {
 }
 
-KPluralHandlingSpinBox::~KPluralHandlingSpinBox()
-{
-    delete d;
-}
+KPluralHandlingSpinBox::~KPluralHandlingSpinBox() = default;
 
 void KPluralHandlingSpinBox::setSuffix(const KLocalizedString &suffix)
 {
@@ -49,3 +49,5 @@ void KPluralHandlingSpinBox::setSuffix(const KLocalizedString &suffix)
     }
 }
 #include "moc_kpluralhandlingspinbox.cpp"
+
+#endif
